@@ -1,45 +1,11 @@
-package HPUX::Ioscan;
-
-use 5.006;
-use strict;
-#use warnings;
-
-require Exporter;
-use AutoLoader qw(AUTOLOAD);
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use HPUX::Ioscan ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(ioscan
-	
-);
-our $VERSION = '1.09_01';
-
-# Preloaded methods go here.
-
-# Autoload methods go after =cut, and are processed by the autosplit program.
-
-
-## start
-
-
+package HPUX::Ioscan ;
+use strict ;
 use FileHandle ;
-use Carp ;
 use vars qw/@ISA @EXPORT $test $VERSION $AUTOLOAD/;
 use Storable;
 
+$VERSION = sprintf "%d.%03d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/;
+
 my @list = 
   qw/bus_type
   cdio
@@ -61,63 +27,6 @@ my @list =
   description
   card_instance/;
 
-my $cache ;
-
-sub ioscan
-  {
-    my %args = @_ ;
-    my $tmp_path ;
-    my $force = $args{force} || 0;
-
-    if (not defined $cache or $force)
-      {
-        my @scan ;
-        if (defined $test)
-          {
-            @scan = @$test ;
-          }
-        else
-          {
-            my $fh = new FileHandle;
-            $fh->open ('ioscan -nF |')
-              or croak "can't open ioscan pipe $!\n";
-            @scan = <$fh>;
-            $fh->close;
-            die "Ioscan error: $!\n" if $! ;
-          }
-
-        foreach my $line (@scan)
-          {
-            #print $line ,"\n";
-            if ($line =~ s/^\s+//)
-              {
-                # file line
-                push @{$cache->{$tmp_path}{device_files}}, split /\s+/,$line ;
-              }
-            else
-              {
-                #device line
-                my @fields = split(':',$line) ;
-                #print "nb field ", scalar @fields, " nb list ", scalar @list, "\n";
-                my $i=0;
-                my %tmp ;
-                while (defined $list[$i])
-                  {
-                    #print "$i: $list[$i],  $fields[$i]\n";
-                    $tmp{$list[$i++]} = $fields[$i] ;
-                  }
-
-                $tmp_path = $tmp{hardware_path} ;
-                $cache->{$tmp_path} = \%tmp ;
-              }
-          }
-      }
-
-    return $cache->{hardware_path} if defined $args{hardware_path};
-
-    return $cache ;
-  }
-
 sub new
   {
     my $debug=0;
@@ -281,20 +190,13 @@ sub get_all_disks_on_controller	{
 	my $instance;
 	my @disks;
 
-	my $cval; # added to support device file sort
-	my $tval; # added to support device file sort
-	my $dval; # added to support device file sort
-	my %devfile;  #added to numerically sort device files
-	my $devfile1; #temp variable in foreach loop
-	my $total; # added to support device file sort
-	my @sorted_disks;
-
 # First find the instance
 	
 	$instance = $self->{ $arglist{controller} }->{card_instance};
 	 print "Instance: $instance\n" if $debug;
-	foreach $mainkey 	( keys %{ $self } )	{
+	foreach $mainkey 	( sort { $a<=>$b } keys %{ $self } )	{
 	 print "MainKey: $mainkey\n" if $debug;
+
 	while ( ($subkey, $subval)= sort each %{ $self->{ $mainkey } } )	{
 	 print "Subkey: $subkey\n" if $debug;
 	 print "Subval: $subval\n" if $debug;
@@ -305,28 +207,8 @@ sub get_all_disks_on_controller	{
 								}
 										}
 							}
-	while (<@disks>) {
-
-	/c(\d+)t(\d+)d(\d+)/;
-
-	$cval = $1;
-	if ( length($cval) < 2 ) { $cval="0".$cval };
-	$tval = $2;
-	if ( length($tval) < 2 ) { $tval="0".$tval };
-	$dval = $3;
-	if ( length($dval) < 2 ) { $dval="0".$dval };
-
-	$total = $cval.$tval.$dval;
-	print "total: $total\n" if $debug;
-
-	$devfile{$total}=$_;
-                   	}
-	foreach $devfile1 ( sort keys %devfile )        {
-        push @sorted_disks, $devfile{$devfile1};
-                                                	}
-	return \@sorted_disks; 
+	return \@disks; 
 				}
-
 sub get_device_hwpath	{
 	my ($self, @subargs) = @_;
 
@@ -349,20 +231,18 @@ sub get_device_hwpath	{
 	while ( ($subkey, $subval)= sort each %{ $self->{ $mainkey } } )	{
 	 print "Subkey: $subkey\n" if $debug;
 	 print "Subval: $subval\n" if $debug;
-	 if (defined ${ $self->{$mainkey}->{device_files} }[0]) {
 			if ( ${ $self->{ $mainkey }->{device_files} }[0] eq "$device_name" )	{
 		$hwpath = $self->{ $mainkey }->{hardware_path};
 		return $hwpath;
 		} 	
-								 }
 								}
 							}
 	$device_name=0;
 	return undef; 
 				}
+
 1;
 __END__
-# Below is stub documentation for your module. You better edit it!
 
 =head1 NAME
 
@@ -612,5 +492,3 @@ under the same terms as Perl itself.
 
 L<ioscan>(1M)
 
-## end
-=cut
